@@ -31,6 +31,9 @@ const NIX_PACKS_VERSION: &str = env!("CARGO_PKG_VERSION");
 // https://status.nixos.org/
 static NIXPKGS_ARCHIVE: &str = "30d3d79b7d3607d56546dd2a6b49e156ba0ec634";
 
+// Debian 11
+static BASE_IMAGE: &str = "debian:buster-slim";
+
 #[derive(Debug)]
 pub struct AppBuilderOptions {
     pub custom_build_cmd: Option<String>,
@@ -391,14 +394,25 @@ impl<'a> AppBuilder<'a> {
         let variables = plan.variables.clone().unwrap_or_default();
 
         // -- Variables
-        let args_string = format!(
-            "ARG {}",
-            variables
-                .iter()
-                .map(|var| var.0.to_string())
-                .collect::<Vec<_>>()
-                .join(" ")
-        );
+        let args_string = if !variables.is_empty() {
+            format!(
+                "ARG {}\nENV {}",
+                // Pull the variables in from docker `--build-arg`
+                variables
+                    .iter()
+                    .map(|var| var.0.to_string())
+                    .collect::<Vec<_>>()
+                    .join(" "),
+                // Make the variables available at runtime
+                variables
+                    .iter()
+                    .map(|var| format!("{}=${}", var.0, var.0))
+                    .collect::<Vec<_>>()
+                    .join(" ")
+            )
+        } else {
+            "".to_string()
+        };
 
         // -- Setup
         let mut setup_files: Vec<String> = vec!["environment.nix".to_string()];
@@ -450,7 +464,27 @@ impl<'a> AppBuilder<'a> {
         }
 
         let dockerfile = formatdoc! {"
-          FROM nixos/nix
+          FROM {base_image}
+
+          RUN apt-get update && apt-get -y upgrade \\
+            && apt-get install --no-install-recommends -y locales curl xz-utils ca-certificates openssl \\
+            && apt-get clean && rm -rf /var/lib/apt/lists/* \\
+            && mkdir -m 0755 /nix && mkdir -m 0755 /etc/nix && groupadd -r nixbld && chown root /nix \\
+            && echo 'sandbox = false' > /etc/nix/nix.conf \\
+            && for n in $(seq 1 10); do useradd -c \"Nix build user $n\" -d /var/empty -g nixbld -G nixbld -M -N -r -s \"$(command -v nologin)\" \"nixbld$n\"; done
+
+          SHELL [\"/bin/bash\", \"-o\", \"pipefail\", \"-c\"]
+          RUN set -o pipefail && curl -L https://nixos.org/nix/install | bash \\
+              && /nix/var/nix/profiles/default/bin/nix-collect-garbage --delete-old
+
+          ENV \\
+            ENV=/etc/profile \\
+            USER=root \\
+            PATH=/nix/var/nix/profiles/default/bin:/nix/var/nix/profiles/default/sbin:/bin:/sbin:/usr/bin:/usr/sbin \\
+            GIT_SSL_CAINFO=/etc/ssl/certs/ca-certificates.crt \\
+            NIX_SSL_CERT_FILE=/etc/ssl/certs/ca-certificates.crt \\
+            NIX_PATH=/nix/var/nix/profiles/per-user/root/channels
+
           RUN nix-channel --update
 
           RUN mkdir /app/
@@ -475,6 +509,7 @@ impl<'a> AppBuilder<'a> {
           {start_copy_cmd}
           {start_cmd}
         ",
+        base_image=BASE_IMAGE,
         setup_copy_cmd=setup_copy_cmd,
         args_string=args_string,
         install_copy_cmd=get_copy_command(&install_files, app_dir),
